==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QTextObjectInterface_shell.cpp <==
#include "QTextObjectInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QTextObjectInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextObjectInterface")
    QTextObjectInterface *_ptr = reinterpret_cast<QTextObjectInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QTextObjectInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QTextObjectInterface_shell) ); }

jmethodID QTextObjectInterface_shell::__shell_javaMethod(int pos) const { return QTextObjectInterface_shell::__shell()->javaMethod(typeid(QTextObjectInterface), pos); }

// emitting (writeShellConstructor)
QTextObjectInterface_shell::QTextObjectInterface_shell()
    : QTextObjectInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QTextObjectInterface::QTextObjectInterface_shell()", QTextObjectInterface_shell::__shell())
    QTextObjectInterface_shell::__shell()->constructed(typeid(QTextObjectInterface));
}

// emitting (writeShellDestructor)
QTextObjectInterface_shell::~QTextObjectInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QTextObjectInterface::~QTextObjectInterface()", QTextObjectInterface_shell::__shell())
    QTextObjectInterface_shell::__shell()->destructed(typeid(QTextObjectInterface));
}

void QTextObjectInterface_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QTextObjectInterface_shell*>(ptr)->QTextObjectInterface_shell::__shell()->tryDeleteShell(typeid(QTextObjectInterface));
}

// emitting Virtual overrides (virtualFunctions)
void QTextObjectInterface_shell::drawObject(QPainter* painter0, const QRectF& rect1, QTextDocument* doc2, int posInDocument3, const QTextFormat& format4)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QTextObjectInterface::", QTextObjectInterface_shell::__shell())
        if(JniEnvironment __jni_env{700}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QTextObjectInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_painter0 = qtjambi_cast<jobject>(__jni_env, painter0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_painter0);
                    jobject __java_rect1 = qtjambi_cast<jobject>(__jni_env, rect1);
                    jobject __java_doc2 = qtjambi_cast<jobject>(__jni_env, doc2);
                    jobject __java_format4 = qtjambi_cast<jobject>(__jni_env, format4);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_painter0, __java_rect1, __java_doc2, posInDocument3, __java_format4);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QTextObjectInterface_shell::__shell()->warnForMethod("QTextObjectInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QTextObjectInterface::");
            } QTJAMBI_TRY_END
        }
    }
}

QSizeF QTextObjectInterface_shell::intrinsicSize(QTextDocument* doc0, int posInDocument1, const QTextFormat& format2)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QTextObjectInterface::", QTextObjectInterface_shell::__shell())
        if(JniEnvironment __jni_env{500}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QSizeF  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QTextObjectInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_doc0 = qtjambi_cast<jobject>(__jni_env, doc0);
                    jobject __java_format2 = qtjambi_cast<jobject>(__jni_env, format2);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_doc0, posInDocument1, __java_format2);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QSizeF >(__jni_env, __java_return_value);
                } else {
                    QTextObjectInterface_shell::__shell()->warnForMethod("QTextObjectInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QTextObjectInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSizeF();
        }
    }else{
        return QSizeF();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QTextObjectInterface_access::__qt_drawObject_QPainter_ptr_cref_QRectF_QTextDocument_ptr_int_cref_QTextFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID rect1, QtJambiNativeID doc2, jint posInDocument3, QtJambiNativeID format4)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QPainter* __qt_painter0 = QtJambiAPI::objectFromNativeId<QPainter>(painter0);
    const QRectF& __qt_rect1 = QtJambiAPI::valueReferenceFromNativeId<QRectF>(rect1);
    QTextDocument* __qt_doc2 = QtJambiAPI::objectFromNativeId<QTextDocument>(doc2);
    const QTextFormat& __qt_format4 = QtJambiAPI::valueReferenceFromNativeId<QTextFormat>(format4);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QTextObjectInterface::drawObject(QPainter * painter, const QRectF & rect, QTextDocument * doc, int posInDocument, const QTextFormat & format)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QTextObjectInterface::drawObject(QPainter * painter, const QRectF & rect, QTextDocument * doc, int posInDocument, const QTextFormat & format).";
    } else {
        drawObject(__qt_painter0, __qt_rect1, __qt_doc2, static_cast<int>(posInDocument3), __qt_format4);
    }
}

jobject QTextObjectInterface_access::__qt_intrinsicSize_QTextDocument_ptr_int_cref_QTextFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID doc0, jint posInDocument1, QtJambiNativeID format2)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QTextDocument* __qt_doc0 = QtJambiAPI::objectFromNativeId<QTextDocument>(doc0);
    const QTextFormat& __qt_format2 = QtJambiAPI::valueReferenceFromNativeId<QTextFormat>(format2);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QTextObjectInterface::intrinsicSize(QTextDocument * doc, int posInDocument, const QTextFormat & format)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QTextObjectInterface::intrinsicSize(QTextDocument * doc, int posInDocument, const QTextFormat & format).";
    } else {
        QSizeF __qt_return_value = intrinsicSize(__qt_doc0, static_cast<int>(posInDocument1), __qt_format2);
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new QTextObjectInterface()
void __qt_construct_QTextObjectInterface(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextObjectInterface()")
    Q_UNUSED(__java_arguments)
    QTextObjectInterface *__qt_this = new(__qtjambi_ptr) QTextObjectInterface_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QTextObjectInterface::QTextObjectInterface()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextObjectInterface_00024Impl_initialize_1native__Lio_qt_gui_QTextObjectInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextObjectInterface::QTextObjectInterface()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextObjectInterface, sizeof(QTextObjectInterface_shell), typeid(QTextObjectInterface), true, &deleter_QTextObjectInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTextObjectInterface_shell
void __qt_destruct_QTextObjectInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextObjectInterface")
    reinterpret_cast<QTextObjectInterface_shell*>(ptr)->~QTextObjectInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextObjectInterface::drawObject(QPainter*,QRectF,QTextDocument*,int,QTextFormat)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextObjectInterface_00024Impl_00024ConcreteWrapper_drawObject_1native_1QPainter_1ptr_1cref_1QRectF_1QTextDocument_1ptr_1int_1cref_1QTextFormat__JJJJIJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID painter0,
 QtJambiNativeID rect1,
 QtJambiNativeID doc2,
 jint posInDocument3,
 QtJambiNativeID format4)
{
    QTJAMBI_TRY {
        QTextObjectInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QTextObjectInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextObjectInterface::drawObject(QPainter*,QRectF,QTextDocument*,int,QTextFormat)", __qt_this)
        static_cast<QTextObjectInterface_access*>(__qt_this)->__qt_drawObject_QPainter_ptr_cref_QRectF_QTextDocument_ptr_int_cref_QTextFormat(__jni_env, __this_nativeId, painter0, rect1, doc2, posInDocument3, format4);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextObjectInterface::intrinsicSize(QTextDocument*,int,QTextFormat)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextObjectInterface_00024Impl_00024ConcreteWrapper_intrinsicSize_1native_1QTextDocument_1ptr_1int_1cref_1QTextFormat__JJIJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID doc0,
 jint posInDocument1,
 QtJambiNativeID format2)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QTextObjectInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QTextObjectInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextObjectInterface::intrinsicSize(QTextDocument*,int,QTextFormat)", __qt_this)
        __java_return_value = static_cast<QTextObjectInterface_access*>(__qt_this)->__qt_intrinsicSize_QTextDocument_ptr_int_cref_QTextFormat(__jni_env, __this_nativeId, doc0, posInDocument1, format2);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QTextObjectInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QTextObjectInterface>("QTextObjectInterface", "io/qt/gui/QTextObjectInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "drawObject", "(Lio/qt/gui/QPainter;Lio/qt/core/QRectF;Lio/qt/gui/QTextDocument;ILio/qt/gui/QTextFormat;)V", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "intrinsicSize", "(Lio/qt/gui/QTextDocument;ILio/qt/gui/QTextFormat;)Lio/qt/core/QSizeF;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QTextObjectInterface, {
        ConstructorInfo(&__qt_construct_QTextObjectInterface, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextObjectInterface);
    registerSizeOfShell(typeId, sizeof(QTextObjectInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QTextObjectInterface* _object = dynamic_cast<QTextObjectInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QTextObjectInterface *object = reinterpret_cast<QTextObjectInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QTextObjectInterface *object = reinterpret_cast<const QTextObjectInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiGui/QTextObjectInterface_shell.cpp <==
#include "QTextObjectInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QTextObjectInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextObjectInterface")
    QTextObjectInterface *_ptr = reinterpret_cast<QTextObjectInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QTextObjectInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QTextObjectInterface_shell) ); }

jmethodID QTextObjectInterface_oshell::__shell_javaMethod(int pos) const { return QTextObjectInterface_shell::__shell()->javaMethod(typeid(QTextObjectInterface), pos); }

// emitting (writeShellDestructor)
QTextObjectInterface_shell::~QTextObjectInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QTextObjectInterface::~QTextObjectInterface()", this)
    QTextObjectInterface_shell::__shell()->destructed(typeid(QTextObjectInterface));
}

// emitting (writeShellConstructor)
QTextObjectInterface_shell::QTextObjectInterface_shell()
    : QTextObjectInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QTextObjectInterface::QTextObjectInterface_shell()", this)
    QTextObjectInterface_shell::__shell()->constructed(typeid(QTextObjectInterface));
}

void QTextObjectInterface_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QTextObjectInterface_oshell*>(ptr)->QTextObjectInterface_oshell::__shell()->tryDeleteShell(typeid(QTextObjectInterface));
}

// emitting Virtual overrides (virtualFunctions)
void QTextObjectInterface_oshell::drawObject(QPainter* painter0, const QRectF& rect1, QTextDocument* doc2, int posInDocument3, const QTextFormat& format4)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        if (JniEnvironmentExceptionHandler __jni_env{700}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QTextObjectInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_painter0 = qtjambi_cast<jobject>(__jni_env, painter0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_painter0);
                    jobject __java_rect1 = qtjambi_cast<jobject>(__jni_env, rect1);
                    jobject __java_doc2 = qtjambi_cast<jobject>(__jni_env, doc2);
                    jobject __java_format4 = qtjambi_cast<jobject>(__jni_env, format4);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_painter0, __java_rect1, __java_doc2, posInDocument3, __java_format4);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QTextObjectInterface_shell::__shell()->warnForMethod("QTextObjectInterface::drawObject(QPainter*,QRectF,QTextDocument*,int,QTextFormat)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QTextObjectInterface::drawObject(QPainter*,QRectF,QTextDocument*,int,QTextFormat)");
            } QTJAMBI_TRY_END
        }
    }
}

QSizeF QTextObjectInterface_oshell::intrinsicSize(QTextDocument* doc0, int posInDocument1, const QTextFormat& format2)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        if (JniEnvironmentExceptionHandler __jni_env{500}) {
            QSizeF  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QTextObjectInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_doc0 = qtjambi_cast<jobject>(__jni_env, doc0);
                    jobject __java_format2 = qtjambi_cast<jobject>(__jni_env, format2);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_doc0, posInDocument1, __java_format2);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                    __qt_return_value = qtjambi_cast<QSizeF>(__jni_env, __java_return_value);
                } else {
                    QTextObjectInterface_shell::__shell()->warnForMethod("QTextObjectInterface::intrinsicSize(QTextDocument*,int,QTextFormat)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QTextObjectInterface::intrinsicSize(QTextDocument*,int,QTextFormat)");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSizeF();
        }
    }else{
        return QSizeF();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QTextObjectInterface_access::__qt_drawObject_QPainter_ptr_cref_QRectF_QTextDocument_ptr_int_cref_QTextFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID rect1, QtJambiNativeID doc2, jint posInDocument3, QtJambiNativeID format4)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QPainter* __qt_painter0 = QtJambiAPI::objectFromNativeId<QPainter>(painter0);
    const QRectF& __qt_rect1 = QtJambiAPI::valueReferenceFromNativeId<QRectF>(rect1);
    QTextDocument* __qt_doc2 = QtJambiAPI::objectFromNativeId<QTextDocument>(doc2);
    const QTextFormat& __qt_format4 = QtJambiAPI::valueReferenceFromNativeId<QTextFormat>(format4);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QTextObjectInterface::drawObject(QPainter * painter, const QRectF & rect, QTextDocument * doc, int posInDocument, const QTextFormat & format)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QTextObjectInterface::drawObject(QPainter * painter, const QRectF & rect, QTextDocument * doc, int posInDocument, const QTextFormat & format).";
    } else {
        drawObject(__qt_painter0, __qt_rect1, __qt_doc2, static_cast<int>(posInDocument3), __qt_format4);
    }
}

jobject QTextObjectInterface_access::__qt_intrinsicSize_QTextDocument_ptr_int_cref_QTextFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID doc0, jint posInDocument1, QtJambiNativeID format2)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QTextDocument* __qt_doc0 = QtJambiAPI::objectFromNativeId<QTextDocument>(doc0);
    const QTextFormat& __qt_format2 = QtJambiAPI::valueReferenceFromNativeId<QTextFormat>(format2);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QTextObjectInterface::intrinsicSize(QTextDocument * doc, int posInDocument, const QTextFormat & format)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QTextObjectInterface::intrinsicSize(QTextDocument * doc, int posInDocument, const QTextFormat & format).";
    } else {
        QSizeF __qt_return_value = intrinsicSize(__qt_doc0, static_cast<int>(posInDocument1), __qt_format2);
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new QTextObjectInterface()
void __qt_construct_QTextObjectInterface(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextObjectInterface()")
    Q_UNUSED(__java_arguments)
    QTextObjectInterface *__qt_this = new(__qtjambi_ptr) QTextObjectInterface_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QTextObjectInterface::QTextObjectInterface()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextObjectInterface_00024Impl_initialize_1native__Lio_qt_gui_QTextObjectInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextObjectInterface::QTextObjectInterface()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextObjectInterface, sizeof(QTextObjectInterface_shell), typeid(QTextObjectInterface), 0, true, &deleter_QTextObjectInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTextObjectInterface_shell
void __qt_destruct_QTextObjectInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextObjectInterface")
    reinterpret_cast<QTextObjectInterface_shell*>(ptr)->~QTextObjectInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextObjectInterface::drawObject(QPainter*,QRectF,QTextDocument*,int,QTextFormat)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextObjectInterface_00024Impl_00024ConcreteWrapper_drawObject_1native_1QPainter_1ptr_1cref_1QRectF_1QTextDocument_1ptr_1int_1cref_1QTextFormat__JJJJIJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID painter0,
 QtJambiNativeID rect1,
 QtJambiNativeID doc2,
 jint posInDocument3,
 QtJambiNativeID format4)
{
    QTJAMBI_TRY {
        QTextObjectInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QTextObjectInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextObjectInterface::drawObject(QPainter*,QRectF,QTextDocument*,int,QTextFormat)", __this_nativeId)
        static_cast<QTextObjectInterface_access*>(__qt_this)->__qt_drawObject_QPainter_ptr_cref_QRectF_QTextDocument_ptr_int_cref_QTextFormat(__jni_env, __this_nativeId, painter0, rect1, doc2, posInDocument3, format4);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextObjectInterface::intrinsicSize(QTextDocument*,int,QTextFormat)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QTextObjectInterface_00024Impl_00024ConcreteWrapper_intrinsicSize_1native_1QTextDocument_1ptr_1int_1cref_1QTextFormat__JJIJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID doc0,
 jint posInDocument1,
 QtJambiNativeID format2)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QTextObjectInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QTextObjectInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextObjectInterface::intrinsicSize(QTextDocument*,int,QTextFormat)", __this_nativeId)
        __java_return_value = static_cast<QTextObjectInterface_access*>(__qt_this)->__qt_intrinsicSize_QTextDocument_ptr_int_cref_QTextFormat(__jni_env, __this_nativeId, doc0, posInDocument1, format2);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QTextObjectInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QTextObjectInterface>("QTextObjectInterface", "io/qt/gui/QTextObjectInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "drawObject", "(Lio/qt/gui/QPainter;Lio/qt/core/QRectF;Lio/qt/gui/QTextDocument;ILio/qt/gui/QTextFormat;)V", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "intrinsicSize", "(Lio/qt/gui/QTextDocument;ILio/qt/gui/QTextFormat;)Lio/qt/core/QSizeF;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QTextObjectInterface, {
        ConstructorInfo(&__qt_construct_QTextObjectInterface, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextObjectInterface);
    registerSizeOfShell(typeId, sizeof(QTextObjectInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QTextObjectInterface* _object = dynamic_cast<QTextObjectInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QTextObjectInterface *object = reinterpret_cast<QTextObjectInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QTextObjectInterface *object = reinterpret_cast<const QTextObjectInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
